@@ -31,7 +31,7 @@ except ImportError:
     pep8 = None
 
 
-__version__ = '0.6.1'
+__version__ = '0.6.2'
 
 
 PEP8_BIN = 'pep8'
@@ -41,20 +41,32 @@ LF = '\n'
 CRLF = '\r\n'
 
 
+def open_with_encoding(filename):
+    """Open file with proper encoding."""
+    try:
+        # Python 3
+        with open(filename, 'rb') as input_file:
+            encoding = tokenize.detect_encoding(input_file.readline)
+
+        return open(filename, encoding=encoding[0])
+    except AttributeError:
+        return open(filename)
+
+
 def read_from_filename(filename, readlines=False):
     """Simple open file, read contents, close file.
+
     Ensures file gets closed without relying on CPython GC.
     Jython requires files to be closed.
+
     """
-    f = open(filename)
-    try:
-        return f.readlines() if readlines else f.read()
-    finally:
-        f.close()
+    with open_with_encoding(filename) as input_file:
+        return input_file.readlines() if readlines else input_file.read()
 
 
 class FixPEP8(object):
-    """fix invalid code
+
+    """Fix invalid code.
 
     [fixed method list]
         - e111
@@ -70,7 +82,9 @@ class FixPEP8(object):
         - w291,w293
         - w391
         - w602,w603,w604
+
     """
+
     def __init__(self, filename, options, contents=None):
         self.filename = filename
         if contents is None:
@@ -90,10 +104,13 @@ class FixPEP8(object):
         self.fix_e241 = self.fix_e221
         self.fix_e242 = self.fix_e224
         self.fix_e261 = self.fix_e262
+        self.fix_e272 = self.fix_e271
+        self.fix_e273 = self.fix_e271
+        self.fix_e274 = self.fix_e271
         self.fix_w191 = self.fix_e101
 
     def _spawn_pep8(self, targetfile):
-        """execute pep8 via subprocess.Popen."""
+        """Execute pep8 via subprocess.Popen."""
         paths = os.environ['PATH'].split(':')
         for path in paths:
             if os.path.exists(os.path.join(path, PEP8_BIN)):
@@ -104,7 +121,7 @@ class FixPEP8(object):
         raise Exception("'%s' is not found." % PEP8_BIN)
 
     def _execute_pep8(self, targetfile):
-        """execute pep8 via python method calls."""
+        """Execute pep8 via python method calls."""
         pep8.options, pep8.args = \
                 pep8.process_options(['pep8'] + self._pep8_options(targetfile))
         # Override sys.stdout to get results from pep8
@@ -120,7 +137,7 @@ class FixPEP8(object):
         return StringIO(result).readlines()
 
     def _pep8_options(self, targetfile):
-        """return options to be passed to pep8."""
+        """Return options to be passed to pep8."""
         return (["--repeat", targetfile] +
                 (["--ignore=" + self.options.ignore]
                  if self.options.ignore else []))
@@ -144,7 +161,7 @@ class FixPEP8(object):
                     completed_lines.append(result['line'])
             else:
                 if self.options.verbose:
-                    sys.stderr.write("'%s' is not defined.\n" % \
+                    sys.stderr.write("'%s' is not defined.\n" %
                             fixed_methodname)
                     info = result['info'].strip()
                     sys.stderr.write("%s:%s:%s:%s\n" % (result['filename'],
@@ -195,7 +212,7 @@ class FixPEP8(object):
         self._fix_whitespace(result, r"\s+\[", "[")
 
     def fix_e221(self, result):
-        """e221, e222 and e223 fixed method"""
+        """Fix E221, E222, and E223."""
         target = self.source[result['line'] - 1]
         c = result['column'] + 1
         fixed = re.sub(r'\s+', ' ', target[c::-1], 1)[::-1] + target[c + 1:]
@@ -212,9 +229,10 @@ class FixPEP8(object):
         self.source[result['line'] - 1] = fixed
 
     def fix_e225(self, result):
+        """Fix whitespace around operator."""
         target = self.source[result['line'] - 1]
-        offset = result['column']
-        fixed = target[:offset - 1] + " " + target[offset - 1:]
+        offset = result['column'] - 1
+        fixed = target[:offset] + ' ' + target[offset:]
 
         # Only proceed if non-whitespace characters match.
         # And make sure we don't break the indentation.
@@ -268,6 +286,19 @@ class FixPEP8(object):
 
         self.source[result['line'] - 1] = fixed
 
+    def fix_e271(self, result):
+        """Fix extraneous whitespace around keywords."""
+        line_index = result['line'] - 1
+        target = self.source[line_index]
+        offset = result['column'] - 1
+
+        # Proceed safely
+        if target[offset] not in [' ', '\t']:
+            return []
+
+        fixed = target[:offset].rstrip() + ' ' + target[offset:].lstrip()
+        self.source[line_index] = fixed
+
     def fix_e301(self, result):
         cr = self.newline
         self.source[result['line'] - 1] = cr + self.source[result['line'] - 1]
@@ -574,10 +605,13 @@ def _find_newline(source):
 def _get_indentword(source):
     sio = StringIO(source)
     indent_word = "    "  # Default in case source has no indentation
-    for t in tokenize.generate_tokens(sio.readline):
-        if t[0] == token.INDENT:
-            indent_word = t[1]
-            break
+    try:
+        for t in tokenize.generate_tokens(sio.readline):
+            if t[0] == token.INDENT:
+                indent_word = t[1]
+                break
+    except tokenize.TokenError:
+        pass
     return indent_word
 
 
@@ -605,14 +639,15 @@ def _analyze_pep8result(result):
 
 def _get_difftext(old, new, filename):
     diff = unified_diff(old, new, 'original/' + filename, 'fixed/' + filename)
-    difftext = [line for line in diff]
-    return "".join(difftext)
+    return "".join(diff)
 
 
 def _priority_key(pep8_result):
     """Key for sorting PEP8 results.
+
     Global fixes should be done first. This is important for things
     like indentation.
+
     """
     priority = ['e101', 'e111', 'w191',  # Global fixes
                 'e702',  # Break multiline statements early
@@ -626,7 +661,7 @@ def _priority_key(pep8_result):
 
 
 def _fix_basic_raise(line, newline):
-    """Fix W602 basic case"""
+    """Fix W602 basic case."""
     sio = StringIO(line)
     is_found_raise = False
     first_comma_found = False
@@ -665,8 +700,13 @@ def _fix_basic_raise(line, newline):
 
 
 class Reindenter(object):
+
     """Reindents badly-indented code to uniformly use four-space indentation.
-    Released to the public domain, by Tim Peters, 03 October 2000."""
+
+    Released to the public domain, by Tim Peters, 03 October 2000.
+
+    """
+
     def __init__(self, input_text):
         self.find_stmt = 1  # next token begins a fresh stmt?
         self.level = 0  # current indent level
@@ -691,8 +731,11 @@ class Reindenter(object):
 
     def run(self):
         tokens = tokenize.generate_tokens(self.getline)
-        for t in tokens:
-            self.tokeneater(*t)
+        try:
+            for t in tokens:
+                self.tokeneater(*t)
+        except IndentationError:
+            return False
         # Remove trailing empty lines.
         lines = self.lines
         while lines and lines[-1] == "\n":
@@ -856,7 +899,7 @@ def fix_file(filename, opts):
 
 
 def main():
-    """tool main"""
+    """Tool main."""
     parser = OptionParser(usage='Usage: autopep8 [options] '
                                 '[filename [filename ...]]',
                           version="autopep8: %s" % __version__,
@@ -879,13 +922,14 @@ def main():
         parser.error('incorrect number of arguments')
 
     try:
-        if opts.in_place:
-            for f in args:
+        if opts.in_place or opts.diff:
+            for f in set(args):
                 fix_file(f, opts)
         else:
             if len(args) > 1:
                 parser.error('autopep8 only takes one filename as argument '
-                             'unless the "--in-place" option is used')
+                             'unless the "--in-place" or "--diff" options are '
+                             'used')
             fix_file(args[0], opts)
     except IOError as error:
         sys.stderr.write(str(error) + '\n')
