@@ -110,6 +110,16 @@ while True:  # My inline comment
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    def test_e101_skip_if_bad_indentation(self):
+        line = """
+try:
+\t    pass
+    except:
+        pass
+""".lstrip()
+        self._inner_setup(line)
+        self.assertEqual(self.result, line)
+
     def test_e111_short(self):
         line = "class Dummy:\n  def __init__(self):\n    pass\n"
         fixed = "class Dummy:\n    def __init__(self):\n        pass\n"
@@ -429,6 +439,30 @@ class Foo(object):
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    def test_e271(self):
+        line = "True and  False\n"
+        fixed = "True and False\n"
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
+    def test_e272(self):
+        line = "True  and False\n"
+        fixed = "True and False\n"
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
+    def test_e273(self):
+        line = "True and\tFalse\n"
+        fixed = "True and False\n"
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
+    def test_e274(self):
+        line = "True\tand False\n"
+        fixed = "True and False\n"
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
     def test_e301(self):
         line = "class k:\n    s = 0\n    def f():\n        print 1\n"
         fixed = "class k:\n    s = 0\n\n    def f():\n        print 1\n"
@@ -841,15 +875,14 @@ class TestOptions(unittest.TestCase):
 
     @py27_and_above
     def test_verbose(self):
-        line = '"' + 80 * 'a' + '"'
+        line = 'bad_syntax)'
         f = open(self.tempfile[1], 'w')
         f.write(line)
         f.close()
         p = Popen(list(AUTOPEP8_CMD_TUPLE) + [self.tempfile[1], '--verbose'],
                   stdout=PIPE, stderr=PIPE)
         verbose_error = p.communicate()[1].decode('utf8')
-        self.assertIn("'fix_e501' is not defined", verbose_error)
-        self.assertIn("too long", verbose_error)
+        self.assertIn("'fix_e901' is not defined", verbose_error)
 
     def test_in_place(self):
         line = "'abc'  \n"
